pio_apply_bus_load_active_power

Function pio_apply_bus_load_active_power 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pio_apply_bus_load_active_power( module: *mut PioModule, bus_id: usize, power: *const PioActivePower, allocation: *const c_char, allocation_len: usize, error: *mut *mut PioError, ) -> *mut PioUpdateReport
Replace aggregate active demand at one bus using the named allocation rule.

The same view invalidation and exclusivity rules as pio_apply_updates apply.

Safety

Pointers and handles must satisfy the crate-level safety requirements. The module handle requires exclusive access, including exclusion of retain.