pio_contingency_resolution_case_component

Function pio_contingency_resolution_case_component 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pio_contingency_resolution_case_component( resolution: *const PioContingencyResolution, case_index: usize, component_index: usize, output: *mut PioContingencyComponentView, error: *mut *mut PioError, ) -> bool
Read one element one case bound to, by zero based case and element position, in action order.

The element’s id.component_type names the table row indexes whether or not the network states an identity for the row, and id.local_id has len 0 when it states none.

Safety

Pointers and handles must satisfy the crate-level safety requirements.