pio_switches

Function pio_switches 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pio_switches( net: *const PioNetwork, from: *mut i64, to: *mut i64, closed: *mut u8, thermal_rating: *mut f64, current_rating: *mut f64, pf: *mut f64, qf: *mut f64, pt: *mut f64, qt: *mut f64, cap: usize, ) -> usize
Write the switch table as parallel arrays, each up to cap entries, and return the total switch count. from/to are external bus ids.