PioMulticonductorNetworkCountsView

Struct PioMulticonductorNetworkCountsView 

#[repr(C)]
pub struct PioMulticonductorNetworkCountsView {
Show 15 fields pub buses: usize, pub line_codes: usize, pub lines: usize, pub switches: usize, pub transformers: usize, pub loads: usize, pub generators: usize, pub inverter_based_resources: usize, pub control_profiles: usize, pub shunts: usize, pub capacitors: usize, pub voltage_sources: usize, pub untyped_objects: usize, pub commands: usize, pub options: usize,
}
Exact table lengths in a multiconductor network.

Source extension extras maps are not exposed through ABI 7. They are retained by PowerIO for same format emission but are not PowerIO domain data.

Fields

buses: usizeline_codes: usizelines: usizeswitches: usizetransformers: usizeloads: usizegenerators: usizeinverter_based_resources: usizecontrol_profiles: usizeshunts: usizecapacitors: usizevoltage_sources: usizeuntyped_objects: usizecommands: usizeoptions: usize