#[unsafe(no_mangle)]pub unsafe extern "C" fn pio_dc_operators_branch_rows(
operators: *const PioDcOperators,
) -> PioSizeViewExpand description
Branch axis row to the analysis branch row it represents: the position in the network’s branch table, with three winding transformer windings after the branches. Borrowed from the handle.
Safety
Pointers and handles must satisfy the crate-level safety requirements.