#[unsafe(no_mangle)]pub unsafe extern "C" fn pio_package_lower_multiconductor_to_balanced(
pkg: *const PioPackage,
base_mva: f64,
errbuf: *mut c_char,
errlen: usize,
) -> *mut PioPackageExpand description
Lower a multiconductor package to a new balanced package. Call
pio_package_multiconductor_to_balanced_preflight_json first when the
caller needs structured blockers for unsupported inputs. base_mva is the
three phase system power base used for the balanced per-unit projection.